mathtools.NonreducedRatio
=========================

.. abjad-lineage:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio

.. autoclass:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.count
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.index
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__add__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__contains__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__eq__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__format__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__ge__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__getitem__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__getslice__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__gt__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__hash__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__iter__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__le__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__len__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__lt__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__mul__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__ne__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__new__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__repr__
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__rmul__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.tuple <tuple>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.count
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.index
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__add__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__contains__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__format__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__getitem__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__getslice__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__hash__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__iter__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__len__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__mul__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__new__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__repr__
   :noindex:

.. automethod:: abjad.tools.mathtools.NonreducedRatio.NonreducedRatio.__rmul__
   :noindex:
